summaryrefslogtreecommitdiffstats
path: root/usr.sbin/pc-sysinstall/backend-query/disk-list.sh
diff options
context:
space:
mode:
Diffstat (limited to 'usr.sbin/pc-sysinstall/backend-query/disk-list.sh')
-rwxr-xr-xusr.sbin/pc-sysinstall/backend-query/disk-list.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/usr.sbin/pc-sysinstall/backend-query/disk-list.sh b/usr.sbin/pc-sysinstall/backend-query/disk-list.sh
index 2616ef9..875b330 100755
--- a/usr.sbin/pc-sysinstall/backend-query/disk-list.sh
+++ b/usr.sbin/pc-sysinstall/backend-query/disk-list.sh
@@ -82,8 +82,8 @@ do
esac
fi
- # Try and find some identification information with camcontrol
- NEWLINE=$(camcontrol identify $DEV 2>/dev/null | sed -ne 's/^device model *//p')
+ # Try and get some identification information from GEOM
+ NEWLINE=$(geom disk list $DEV 2>/dev/null | sed -ne 's/^ descr: *//p')
if [ -z "$NEWLINE" ]; then
NEWLINE=" <Unknown Device>"
fi
OpenPOWER on IntegriCloud